summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/interfaces/filterinterface.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/interfaces/filterinterface.h')
-rw-r--r--kdevdesigner/interfaces/filterinterface.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kdevdesigner/interfaces/filterinterface.h b/kdevdesigner/interfaces/filterinterface.h
index bb6b94b8..abca17b4 100644
--- a/kdevdesigner/interfaces/filterinterface.h
+++ b/kdevdesigner/interfaces/filterinterface.h
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000-2001 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -27,26 +27,26 @@
#ifndef FILTERINTERFACE_H
#define FILTERINTERFACE_H
-#include <private/qcom_p.h>
+#include <private/tqcom_p.h>
// {ea8cb381-59b5-44a8-bae5-9bea8295762a}
#ifndef IID_ImportFilter
-#define IID_ImportFilter QUuid( 0xea8cb381, 0x59b5, 0x44a8, 0xba, 0xe5, 0x9b, 0xea, 0x82, 0x95, 0x76, 0x2a )
+#define IID_ImportFilter TQUuid( 0xea8cb381, 0x59b5, 0x44a8, 0xba, 0xe5, 0x9b, 0xea, 0x82, 0x95, 0x76, 0x2a )
#endif
/*! If you write a filter plugin to import dialogs or other user
- interfaces from a different format than .ui into the Qt Designer,
+ interfaces from a different format than .ui into the TQt Designer,
implement this interface in that plugin.
You also have to implement the function featureList() (\sa
- QFeatureListInterface) and return there all filters (names of it)
+ TQFeatureListInterface) and return there all filters (names of it)
which this interface provides.
*/
-struct ImportFilterInterface : public QFeatureListInterface
+struct ImportFilterInterface : public TQFeatureListInterface
{
- /*! This function is called by Qt Designer to open the file \a
- filename using the filter \a filter. Qt Designer expects to get
+ /*! This function is called by TQt Designer to open the file \a
+ filename using the filter \a filter. TQt Designer expects to get
back one or more .ui files, which it can open then. In the
implementation of the interface you have to return these
filenames, which the filter created, in this function.*/
@@ -57,10 +57,10 @@ struct ImportFilterInterface : public QFeatureListInterface
// {c32a07e0-b006-471e-afca-d227457a1280}
#ifndef IID_ExportFilterInterface
-#define IID_ExportFilterInterface QUuid( 0xc32a07e0, 0xb006, 0x471e, 0xaf, 0xca, 0xd2, 0x27, 0x45, 0x7a, 0x12, 0x80 )
+#define IID_ExportFilterInterface TQUuid( 0xc32a07e0, 0xb006, 0x471e, 0xaf, 0xca, 0xd2, 0x27, 0x45, 0x7a, 0x12, 0x80 )
#endif
-struct ExportFilterInterface : public QFeatureListInterface
+struct ExportFilterInterface : public TQFeatureListInterface
{
// virtual TQStringList export( const TQString& filter, const TQString& filename ) = 0;
};
@@ -1,15 +1,15 @@
** Copyright (C) 2000-2001 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the